<p align="center">
<img src="https://drive.google.com/uc?id=1pMUqyvgMkhGYoLz3jBibZDl3J63HEcCC">
</p>

# <u>A</u>synchronous <u>C</u>omponent <u>B</u>ase

[![Code style: crackerjack](https://img.shields.io/badge/code%20style-crackerjack-000042)](https://github.com/lesleslie/crackerjack)


Asynchronous Component Base, or 'acb', is a collection of modular
components (actions / adapters) that provide the building blocks for rapid,
asynchronous, application development.

More documentation is on the way!

## Installation

```
pdm add acb
```

## Actions


## Adapters


### Configuration


### Dependency Injection


### Debug


## Acknowledgements

ACB "blocks" logo used by permission from <a href="https://andycoeband.com">Andy Coe Band</a>


## License

BSD-3-Clause
